==> encoDnaseI_0.1.6.tar.gz: encoDnaseI/R/wrc.R <==
locmax = function (x, y, bin = 50000) {
    fx = x[is.finite(y)]
    fy = y[is.finite(y)]
    coax = floor(fx/bin) * bin
    sy = split(fy, coax)
    list(x = as.numeric(names(sy)), y = sapply(sy, max))
}

alicor = function(x1, y1, x2, y2, bin = 50000) {
    prof1 = locmax(x1, y1, bin)
    prof2 = locmax(x2, y2, bin)
# there is no guarantee that these are on the same domain; use first to define domain
    domx = seq(min(x1), max(x1), bin)
    yon1 = approx(prof1$x, prof1$y, domx)
    yon2 = approx(prof2$x, prof2$y, domx)
    cor(yon1$y, yon2$y)
}

#ALICOR = function(ssr, dns=rawCD4, bin=50000) {
#    sy = p.value(ssr@.Data[[1]])
#    rsn = names(sy)
#    locstr = snpLocs.Hs(chrnum(ssr@chrnum), rsid(rsn))
#    aloc = locstr["loc", ]
# rloc = aloc - aloc[1] + 1
# if (length(ssr@activeSnpInds)>0) rloc=rloc[ssr@activeSnpInds]
# x1 = rloc
# y1 = sy #ssr[[1]][, "p.1df"]
# x2 = chromStarts(dns)+24.5
# y2 = dataVals(dns)
# alicor(x1, y1, x2, y2, bin)
#}

ALICOR = function (ssr, dns = rawCD4, bin = 50000) 
{
    sy = p.value(ssr@.Data[[1]])
    rsn = names(sy)
    locstr = snpLocs.Hs(ssr@chrnum, rsid(rsn))
    aloc = locstr["loc", ]
    rloc = aloc - aloc[1] + 1
#    if (length(ssr@activeSnpInds) > 0) 
#        rloc = rloc[ssr@activeSnpInds]
    x1 = aloc
    y1 = -log10(sy)
    x2 = chromStarts(dns) + 24.5
    y2 = dataVals(dns)
    alicor(x1, y1, x2, y2, bin)
}



wrc = function(x1, y1, x2, y2, dropsize=10000, nrun=3) {
 # weighted recursive coupling
   loc1 = x1[sm1 <- which.max(y1)[1]]
   loc2 = x2[sm2 <- which.max(y2)[1]]
   val1 = abs(y1[sm1])
   kill1 = c(loc1-dropsize, loc1+dropsize)
   x1 = x1[ ok <- which(x1<kill1[1] | x1>kill1[2] )]
   y1 = y1[ok]
   kill2 = c(loc2-dropsize, loc2+dropsize)
   x2 = x2[ ok <- which(x2<kill2[1] | x2>kill2[2] )]
   y2 = y2[ok]
   ans = c(dist=abs(loc1-loc2)/val1,loc=loc1)
 if (nrun > 0) 
   return(c(ans, Recall(x1, y1, x2, y2, dropsize, nrun-1)))
 else return(ans)
}

WRC = function(ssr, dns=d19, dropsize=10000, nrun=2) {
 x1 = ssr@locs
 y1 = abs(ssr$trat)
 x2 = chromStarts(dns)+24.5
 y2 = dataVals(dns)
 ans <- wrc(x1, y1, x2, y2, dropsize=dropsize, nrun=nrun)
 nn = names(ans)[grep("dist", names(ans))]
 ss = strsplit(nn,"\\.")
 ans = t(matrix(ans,nr=2))
 colnames(ans)  = c("score", "loc")
 rownames(ans) = sapply(ss, "[", 2)
 ans
}

==> encoDnaseI_0.1.16.tar.gz: encoDnaseI/R/wrc.R <==
locmax = function (x, y, bin = 50000) {
    fx = x[is.finite(y)]
    fy = y[is.finite(y)]
    coax = floor(fx/bin) * bin
    sy = split(fy, coax)
    list(x = as.numeric(names(sy)), y = sapply(sy, max))
}

alicor = function(x1, y1, x2, y2, bin = 50000) {
    prof1 = locmax(x1, y1, bin)
    prof2 = locmax(x2, y2, bin)
# there is no guarantee that these are on the same domain; use first to define domain
    domx = seq(min(x1), max(x1), bin)
    yon1 = approx(prof1$x, prof1$y, domx)
    yon2 = approx(prof2$x, prof2$y, domx)
    cor(yon1$y, yon2$y, use="pair")
}

#ALICOR = function(ssr, dns=rawCD4, bin=50000) {
#    sy = p.value(ssr@.Data[[1]])
#    rsn = names(sy)
#    locstr = snpLocs.Hs(chrnum(ssr@chrnum), rsid(rsn))
#    aloc = locstr["loc", ]
# rloc = aloc - aloc[1] + 1
# if (length(ssr@activeSnpInds)>0) rloc=rloc[ssr@activeSnpInds]
# x1 = rloc
# y1 = sy #ssr[[1]][, "p.1df"]
# x2 = chromStarts(dns)+24.5
# y2 = dataVals(dns)
# alicor(x1, y1, x2, y2, bin)
#}

ALICOR = function (ssr, dns = rawCD4, bin = 50000, locstr) 
{
    sy = p.value(ssr@.Data[[1]])
    rsn = names(sy)
#    locstr = snpLocs.Hs(ssr@chrnum, rsid(rsn))
    aloc = locstr["loc", ]
    rloc = aloc - aloc[1] + 1
#    if (length(ssr@activeSnpInds) > 0) 
#        rloc = rloc[ssr@activeSnpInds]
    x1 = aloc
    y1 = -log10(sy)
    x2 = chromStarts(dns) + 24.5
    y2 = dataVals(dns)
    alicor(x1, y1, x2, y2, bin)
}



wrc = function(x1, y1, x2, y2, dropsize=10000, nrun=3) {
 # weighted recursive coupling
   loc1 = x1[sm1 <- which.max(y1)[1]]
   loc2 = x2[sm2 <- which.max(y2)[1]]
   val1 = abs(y1[sm1])
   kill1 = c(loc1-dropsize, loc1+dropsize)
   x1 = x1[ ok <- which(x1<kill1[1] | x1>kill1[2] )]
   y1 = y1[ok]
   kill2 = c(loc2-dropsize, loc2+dropsize)
   x2 = x2[ ok <- which(x2<kill2[1] | x2>kill2[2] )]
   y2 = y2[ok]
   ans = c(dist=abs(loc1-loc2)/val1,loc=loc1)
 if (nrun > 0) 
   return(c(ans, Recall(x1, y1, x2, y2, dropsize, nrun-1)))
 else return(ans)
}

WRC = function(ssr, dns=d19, dropsize=10000, nrun=2) {
 x1 = ssr@locs
 y1 = abs(ssr$trat)
 x2 = chromStarts(dns)+24.5
 y2 = dataVals(dns)
 ans <- wrc(x1, y1, x2, y2, dropsize=dropsize, nrun=nrun)
 nn = names(ans)[grep("dist", names(ans))]
 ss = strsplit(nn,"\\.")
 ans = t(matrix(ans,nr=2))
 colnames(ans)  = c("score", "loc")
 rownames(ans) = sapply(ss, "[", 2)
 ans
}
